@@ -27,7 +27,7 @@ Usage::
     list_topics_detection_jobs_paginator: ListTopicsDetectionJobsPaginator = client.get_paginator("list_topics_detection_jobs")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_comprehend.type_defs import (
     DocumentClassificationJobFilterTypeDef,
@@ -71,7 +71,7 @@ class ListDocumentClassificationJobsPaginator(Boto3Paginator):
         self,
         Filter: DocumentClassificationJobFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDocumentClassificationJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDocumentClassificationJobsResponseTypeDef]:
         """
         [ListDocumentClassificationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassificationJobs.paginate)
         """
@@ -86,7 +86,7 @@ class ListDocumentClassifiersPaginator(Boto3Paginator):
         self,
         Filter: DocumentClassifierFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDocumentClassifiersResponseTypeDef, None, None]:
+    ) -> Iterator[ListDocumentClassifiersResponseTypeDef]:
         """
         [ListDocumentClassifiers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListDocumentClassifiers.paginate)
         """
@@ -101,7 +101,7 @@ class ListDominantLanguageDetectionJobsPaginator(Boto3Paginator):
         self,
         Filter: DominantLanguageDetectionJobFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListDominantLanguageDetectionJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListDominantLanguageDetectionJobsResponseTypeDef]:
         """
         [ListDominantLanguageDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListDominantLanguageDetectionJobs.paginate)
         """
@@ -116,7 +116,7 @@ class ListEntitiesDetectionJobsPaginator(Boto3Paginator):
         self,
         Filter: EntitiesDetectionJobFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListEntitiesDetectionJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListEntitiesDetectionJobsResponseTypeDef]:
         """
         [ListEntitiesDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListEntitiesDetectionJobs.paginate)
         """
@@ -131,7 +131,7 @@ class ListEntityRecognizersPaginator(Boto3Paginator):
         self,
         Filter: EntityRecognizerFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListEntityRecognizersResponseTypeDef, None, None]:
+    ) -> Iterator[ListEntityRecognizersResponseTypeDef]:
         """
         [ListEntityRecognizers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListEntityRecognizers.paginate)
         """
@@ -146,7 +146,7 @@ class ListKeyPhrasesDetectionJobsPaginator(Boto3Paginator):
         self,
         Filter: KeyPhrasesDetectionJobFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListKeyPhrasesDetectionJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListKeyPhrasesDetectionJobsResponseTypeDef]:
         """
         [ListKeyPhrasesDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListKeyPhrasesDetectionJobs.paginate)
         """
@@ -161,7 +161,7 @@ class ListSentimentDetectionJobsPaginator(Boto3Paginator):
         self,
         Filter: SentimentDetectionJobFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListSentimentDetectionJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListSentimentDetectionJobsResponseTypeDef]:
         """
         [ListSentimentDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListSentimentDetectionJobs.paginate)
         """
@@ -176,7 +176,7 @@ class ListTopicsDetectionJobsPaginator(Boto3Paginator):
         self,
         Filter: TopicsDetectionJobFilterTypeDef = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListTopicsDetectionJobsResponseTypeDef, None, None]:
+    ) -> Iterator[ListTopicsDetectionJobsResponseTypeDef]:
         """
         [ListTopicsDetectionJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/comprehend.html#Comprehend.Paginator.ListTopicsDetectionJobs.paginate)
         """
